@@ -1,4 +1,5 @@
 from finolog.services.contractor_service import FinologContractorService
+from finolog.services.country_service import FinologCountryService
 from finolog.services.document_service import FinologDocumentService
 from finolog.services.requisite_service import FinologRequisiteService
 
@@ -13,3 +14,4 @@ class FinologClient:
         self.contractor = FinologContractorService(api_token=api_token, biz_id=self.biz_id)
         self.document = FinologDocumentService(api_token=api_token, biz_id=self.biz_id)
         self.requisite = FinologRequisiteService(api_token=api_token, biz_id=self.biz_id)
+        self.country = FinologCountryService(api_token=api_token)
